![build](https://github.com/shubhamraj2202/pybot-chatgpt/actions/workflows/github-actions.yml/badge.svg?event=push)
[![codecov](https://codecov.io/gh/shubhamraj2202/pybot-chatgpt/branch/main/graph/badge.svg?token=X9KIXXBOAV)](https://codecov.io/gh/shubhamraj2202/pybot-chatgpt)
# PYBOT-ChatGPT
Python Bot which wraps ChatGPT API

# Uses


# Project Setup:
>1. RunCmd:
    `open ~/.secrets`
>2. Update the Secrets File with Token and Save - (Note: ORG_APIKEY_CHATGPT is Optional):
    `export APIKEY_CHATGPT=<Your ChatGPT API Token>`
    `export ORG_APIKEY_CHATGPT=<Organistaion API Token>`
>3. RunCmd:
    `source setup.sh`

# Uploaded On:
https://pypi.org/project/pyhelper-misc/
